import { useContext, useMemo } from 'react';
import PdeContext from '../contexts/PdeContext';
/**
 * Hook to use a feature toggle
 * @param {string} experimentName
 * @return {{variation: string}}
 */

export default function useExperiment(experimentName) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useExperiment] pde is required to work');
  var variation = useMemo(function () {
    return pde.activateExperiment({
      name: experimentName
    });
  }, [experimentName, pde]);
  return {
    variation: variation,
    trackExperiment: pde.trackExperiment.bind(pde)
  };
}